* OBJECTIVE: Assemble Progressa data for running the DT Regressions
* SOURCE SURVEY FILES FOR PROGRESA PROGRAM DOWNLOADED FROM: http://evaluacion.oportunidades.gob.mx:8010/en/eval_cuant/bases_cuanti.php
* The website above also has labeled versions of the surveys to map the codes below to specific questions.

* Progresa Transfer data can be found :  http://evaluacion.oportunidades.gob.mx:8010/en/eval_cuant/bases_cuanti.php


*********************
*** Preliminaries ***
*********************

clear
set more off

local datdir = "/Users/titanalon/Documents/RA/Doepke/Progresa Project/Raw Data Sets" //Where is the raw data?
local outdir = "/Users/titanalon/Documents/RA/Doepke/Progresa Project/Processed Data Sets" //Where should cleaned data be saved?


************************
*** Clean Data Files ***
************************

****************
* ENCASEH 1997 *
****************

use "`datdir'/Dataset_encaseh.dta", clear

* Drop observations with missing HH identifiers
drop if folio==.

* Defining HH Characteristics

* Gender
gen sex = p11 // males = 1, female=2

* Age
gen age = p08

* Child <16 identifier
gen kid=0
replace kid = 1 if age<=16

* Adult indentifier
gen adult=0
replace adult = 1 if age>16

*Marital Status
gen married = 0
replace married=1 if p36==2

* Program Eligibility ("Poverty" indicator) in 1997
gen elig97=0
replace elig97 = 1 if pobre==2

* Treatment Group Identifier in 1997
gen treat97=0
replace treat97 =1 if contba==1


* Education
gen educ=. 
replace educ=0 if p20==0
replace educ=1 if p20==11
replace educ=2 if p20==21
replace educ=3 if p20==31

replace educ=4 if p20==12
replace educ=5 if p20==22
replace educ=6 if p20==32
replace educ=7 if p20==42
replace educ=8 if p20==52
replace educ=9 if p20==62

replace educ=10 if p20==13
replace educ=11 if p20==23
replace educ=12 if p20==33

replace educ=13 if p20==14
replace educ=14 if p20==24
replace educ=15 if p20==34
replace educ=16 if p20==44

replace educ=13 if p20==15
replace educ=14 if p20==25
replace educ=15 if p20==35

replace educ=16 if p20==16
replace educ=17 if p20==26
replace educ=18 if p20==36
replace educ=19 if p20==46
replace educ=20 if p20==56
replace educ=21 if p20==66
replace educ=22 if p20==76

replace educ=21 if p20==17
replace educ=22 if p20==27
replace educ=23 if p20==37
replace educ=24 if p20==47

* Parental Characteristics (These are parents because we will remove households without two adults living maritally
gen meduc=0
replace meduc=educ if (sex==1)&(adult==1)

gen feduc=0
replace feduc=educ if (sex==2)&(adult==1)

gen mage=0
replace mage=age if (sex==1)&(adult==1)

gen fage=0
replace fage=age if (sex==2)&(adult==1)

* Characteristics of HH Head
gen hhd_age=0
replace hhd_age  = age if renglon==1

gen hhd_educ=0
replace hhd_educ = educ if renglon==1

* HH Size
gen hd_size=0
replace hd_size=p07

* Keep Only Households with Father & Mother
gen father_present=0
replace father_present=1 if (renglon==1)&(sex==1)   
replace father_present=1 if (renglon~=1)&(sex==1)&(p12==2)

gen mother_present=0
replace mother_present=1 if (renglon==1)&(sex==2)    
replace mother_present=1 if (renglon~=1)&(sex==2)&(p12==2)   

* Land Holdings of HH

gen landcount = 0
foreach var of varlist p68*{
	replace landcount = landcount+1 if ( `var'==.)|( `var'==99)|( `var'==98)
	}

gen land=0

foreach var of varlist p68* {
	replace  `var'=0 if ( `var'==.)|( `var'==99)|( `var'==98)
	replace land=land+ `var' 
} 


replace land= . if landcount==5

* Collapse Observations to the HH Level

collapse (sum) nkids=kid nadults=adult ncouples=married (max) hhd_age hhd_educ hd_size father_present mother_present meduc feduc mage fage land elig97 treat97, by(folio)

* Drop Households without two adults living Maritally
drop if ncouples~=2
drop if nadults>2 
drop if father_present==0
drop if mother_present==0

tempfile data97
save `data97', replace


******************
* ENCEL Oct 1998 *
******************


use "`datdir'/ENCEL98o_2.dta", clear // read in data

* Ages
gen anos=.
replace anos=r002

* Kid Identifier
gen kid=0
replace kid=1 if anos<=16

* Adult Indicator
gen adult=0
replace adult=1 if anos>16

* Gender
gen sex=.
replace sex=1 if (r009==1)
replace sex=2 if (r009==2)

* Number Kids in School
gen attend_school=0
replace attend_school=1 if (kid==1)&(r046==1)

* Female Children
gen fkid=0
replace fkid=1 if (kid==1)&(sex==2)

* HH Size Indicator for collapse
gen hh_size=1

* Kids in Primary School
gen kid_primary=.
replace kid_primary=1 if (attend_school==1)&(anos<=13)

* Marriage Indicator
gen married=0
replace married=1 if (r057==2)

* Eligibility
gen elig=0
replace elig=1 if pobre==2

* Treatment
gen treat=0
replace treat=1 if contba==1

* Keep Track of Missing Female Income
gen hhw_mis_inc=0
replace hhw_mis_inc=1 if (r059==.)&(r060==.)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (r059==9)&(r060==.)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (r059==.)&(r060==9)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (r059==9)&(r060==9)&(sex==2)&(anos>16)


*** EXPENDITURES OCT 1998 ***


* Clothing in last 6 Months
foreach var of varlist r1480* {
 replace `var' = 0 if (`var'==9999)|(`var'==.)
}

foreach var of varlist r1470* {
 replace `var' = 0 if (`var'==9999)|(`var'==.)
}

* With shoes
gen women_clothing=(r14801+r14805)/6
gen men_clothing=(r14802+r14806)/6
gen girls_clothing=(r14704+r14803)/6
gen boys_clothing=(r14705+r14804)/6

* Without shoes
*gen women_clothing=(r14801)/6
*gen men_clothing=(r14802)/6
*gen girls_clothing=(r14704)/6
*gen boys_clothing=(r14705)/6

* Transportation in Last Week
replace r14501=0 if (r14501==999)|(r14501==.)
replace r14502=0 if (r14502==999)|(r14502==.)
gen transport=(r14501+r14502)*4

*Tobacco in the Last Week
replace r14503=0 if (r14503==988)|(r14503==999)|(r14503==.)
gen tobacco=r14503*4

* Services during last month (r14604-medical consulations) 
replace r14604=0 if (r14604==999)|(r14604==.)
gen services=r14604

*Food in the Last Week
foreach var of varlist r129* {
 replace `var' = 0 if (`var'==988)|(`var'==999)|(`var'==.)
}
gen food=0
foreach var of varlist r129* {
 replace food=food+`var' 
}
replace food=food*4

*Alcohol in the Last Week
gen alco=r12933*4

* Typical Weekly Expenditures
replace r141=0 if (r141==999)|(r141==.)
gen expenditure2=r141*4


*** INCOME OCT 1998 ***


* Income from "Main Job"
replace r068a=0 if (r068a==98888)| (r068a==99999)| (r068a==.)

gen period=0
replace period=30 if r068b==1
replace period=4 if r068b==2
replace period=2 if r068b==3
replace period=1 if r068b==4
replace period=1/12 if r068b==5
replace period=0 if r068b==8
replace period=0 if r068b==9
replace period=0 if r068b==.

gen main_job=0
replace main_job=r068a*period

* Income from "Other Jobs"
replace r074a=0 if (r074a==98888)| (r074a==99999)| (r074a==.)

gen period2=0
replace period2=30 if r074b==1
replace period2=4 if r074b==2
replace period2=2 if r074b==3
replace period2=1 if r074b==4
replace period2=1/12 if r074b==5
replace period2=0 if r074b==8
replace period2=0 if r074b==9
replace period2=0 if r074b==.

gen other_job=0
replace other_job=r074a*period2


* Additional Benefits
replace r071=0 if (r071==98888)| (r071==99999)| (r071==.)

gen period22=0
replace period22=30 if r070==1
replace period22=4 if r070==2
replace period22=2 if r070==3
replace period22=1 if r070==4
replace period22=1/12 if r070==5
replace period22=0 if r070==8
replace period22=0 if r070==9
replace period22=0 if r070==.

gen benef=0
replace benef=r071*period22

* Additional Services Provided
gen pay_serv=0
foreach var of varlist r0780* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace pay_serv=pay_serv+`var'
} 
foreach var of varlist r0790* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace pay_serv=pay_serv-`var'
} 
replace pay_serv=0 if pay_serv<0

* Define Total Income
gen income=0
replace income=main_job+other_job+pay_serv+benef


gen fincome=0
replace fincome=income if (sex==2)&(adult==1)

gen mincome=0
replace mincome=income if (sex==1)&(adult==1)

* Keep income subcategories for women for summary charts
gen finc_main = 0
replace finc_main = main_job if (sex==2)&(adult==1)

gen finc_ojob = 0
replace finc_ojob = other_job if (sex==2)&(adult==1)

gen finc_payserv = 0
replace finc_payserv = pay_serv if (sex==2)&(adult==1)



*Adult woman does not work
*r059: 4-no trabajo; r060: 6- no trabajo (verifiation)
gen nfj=0
replace nfj=1 if (sex==2)&(r059==4)&(r060==6)&(anos>16)
replace nfj=0 if  (sex==2)&(r059==.)&(r060==.)&(anos>16)

gen faj = 0
replace faj = 1 if (sex==2)&(r059==1)&(anos>16) //time "at job" last week

* Income Support
foreach var of varlist r0880*d {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
} 

* Renglon table
foreach X in 1 2 3 4 5 6 7 8 9 10 {
	gen num`X'=0
	replace num`X'=1 if (renglon==`X')&(sex==1)&(adult==1)
	replace num`X'=2 if (renglon==`X')&(sex==2)&(adult==1)
	replace num`X'=3 if (renglon==`X')&(adult==0)	
}


foreach var of varlist r0880*c {
	gen p`var'=0
	replace p`var'=30 if `var' ==1
	replace p`var'=4 if `var' ==2
	replace p`var'=2 if `var' ==3
	replace p`var'=1 if `var' ==4
	replace p`var'=1/2 if `var' ==5
	replace p`var'=1/12 if `var' ==6
	replace p`var'=0 if `var' ==7
	replace p`var'=0 if `var' ==8
	replace p`var'=0 if `var' ==9
	replace p`var'=0 if `var' ==.
} 

* receiver of support
* amount of support
foreach X in 1 2 3 4 5 {
	gen sup`X'_rec=r0880`X'b1
	gen sup`X'_am=r0880`X'd*pr0880`X'c		
}



*** INVESTMENT GOODS OCT 1998 ***

* Livestock
gen livestock=0
*in the last 6 month have you purchased any animals? how much did it cost?
foreach var of varlist r168* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace livestock=livestock+`var'/6
} 

*in the last 6 month have you sold any animals? how much did you get?
foreach var of varlist r170* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace livestock=livestock-`var'/6
} 

* Expenditures on House Repairs\Upgrades
gen ind_fixhouse=0
*over the past year have you made any improvements in...?
foreach X in 1 2 3 4 5 6 7 8 9 {
	replace ind_fixhouse=1 if r1520`X'==1
} 

*How much invested in improving?? /12 to get monthly data
gen fixhouse=0
foreach var of varlist r1540* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace fixhouse=fixhouse+`var'/12
}
*

* Durables
*Did you purchase (ITEM) in the last year?
*How much does the item cost? Add only those bought over the past year/12 to get monthly data

gen ind_durables=0 
gen durables=0

foreach X in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 16{
	replace ind_durables=1 if r150`X'==1
	replace r151`X' = 0 if (r151`X'==99999)|(r151`X'==98888)|(r151`X'==.)
	replace durables=durables+r151`X'/12 if r150`X'==1	
}
*

* Land
gen landcount = 0
foreach var of varlist r1560* { 
	replace landcount = landcount+1 if `var' ==.
	}


gen land=0 //How many acres is the estate (first, second)
foreach var of varlist r1560* {
	replace  `var'=0 if ( `var'==.)
	replace land=land+ `var' 
} 

replace land = . if landcount==6

* Collapse to Household Level

collapse (sum) nkids=kid nadults=adult ncouples=married nkids_school = attend_school nfkids =fkid nkids_prim=kid_primary  hh_size income food alco tobacco transport services women_clothing men_clothing girls_clothing boys_clothing expenditure2 hhw_mis_inc livestock  land (max) elig treat finc_* fincome mincome  sup* num* nfj faj ind_fixhouse fixhouse ind_durables durables,  by(folio)

* HH Sample
drop if ncouples~=2
drop if nadults>2 
drop if hhw_mis_inc>0 // missing female income


* Female Income Share support data

gen fsup=0
gen msup=0
gen kidsup=0

foreach Y in 1 2 3 4 5 {
foreach X in 1 2 3 4 5 6 7 8 9 10 {
	replace msup=msup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==1)
	replace fsup=fsup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==2)
	replace kidsup=kidsup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==3)	
}
}
*

* save datafile
tempfile data98_2
save `data98_2', replace


******************
* ENCEL Mar 1999 *
******************

use "`datdir'/ENCEL99m_1.dta", clear // read in data

gen anos=.
replace anos=m002

gen kid=0
replace kid=1 if anos<=16

gen sex=.
replace sex=1 if (m009==1)
replace sex=2 if (m009==2)

* Kids in Schools
gen attend_school=0
replace attend_school=1 if (kid==1)&(m047==1)

* Female children
gen fkid=0
replace fkid=1 if (kid==1)&(sex==2)

* HH Size for collapse
gen hh_size=1

* Kids in Primary School
gen kid_primary=.
replace kid_primary=1 if (attend_school==1)&(anos<=13)

* Adult indicator
gen adult=0
replace adult=1 if anos>16

* Marital Status
gen married=0
replace married=1 if (m060==2)|(m060==3)|(m060==4)

* Female missing incomes
gen hhw_mis_inc=0
replace hhw_mis_inc=1 if (m062==.)&(m063==.)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (m062==9)&(m063==.)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (m062==.)&(m063==9)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (m062==9)&(m063==9)&(sex==2)&(anos>16)

* Treatment\Eligibility Indicators
gen elig=0
replace elig=1 if pobreden==2

gen treat=0
replace treat=1 if contba==1

*** EXPENDITURES MAR 1999 ***

* Clothing in last six months
foreach var of varlist m1100* {
 replace `var' = 0 if (`var'==9999)|(`var'==.)
}

foreach var of varlist m1090* {
 replace `var' = 0 if (`var'==9999)|(`var'==.)
}

*With shoes
gen women_clothing=(m11001+m11005)/6
gen men_clothing=(m11002+m11006)/6
gen girls_clothing=(m10904+m11003)/6
gen boys_clothing=(m10905+m11004)/6

*Without shoes
*gen women_clothing=(m11001)/6
*gen men_clothing=(m11002)/6
**gen girls_clothing=(m10904)/6
*gen boys_clothing=(m10905)/6

* Transportation in last week
replace m10701=0 if (m10701==999)|(m10701==.)
replace m10702=0 if (m10702==999)|(m10702==.)
gen transport=(m10701+m10702)*4

*Tobacco in the last week
replace m10703=0 if (m10703==988)|(m10703==999)|(m10703==.)
gen tobacco=m10703*4

* Services in last month
replace m10804=0 if (m10804==999)|(m10804==.)
gen services=m10804

*Food in past week
foreach var of varlist m091* {
 replace `var' = 0 if (`var'==988)|(`var'==999)|(`var'==.)
}
gen food=0
foreach var of varlist m091* {
 replace food=food+`var' 
}
replace food=food*4

*Alcohol in past week
gen alco=m09136*4

* Typical Expenditures per week
replace m103=0 if (m103==999)|(m103==.)
gen expenditure2=m103*4


*** INCOME MAR 1999 ***


* Main Job Income
replace m069a=0 if (m069a==98888)| (m069a==99999)| (m069a==.)

gen period=0
replace period=30 if m069b==1
replace period=4 if m069b==2
replace period=2 if m069b==3
replace period=1 if m069b==4
replace period=1/12 if m069b==5
replace period=0 if m069b==8
replace period=0 if m069b==9
replace period=0 if m069b==.

gen main_job=0
replace main_job=m069a*period

* Other Jobs
replace m072a=0 if (m072a==98888)| (m072a==99999)| (m072a==.)

gen period2=0
replace period2=30 if m072b==1
replace period2=4 if m072b==2
replace period2=2 if m072b==3
replace period2=1 if m072b==4
replace period2=1/12 if m072b==5
replace period2=0 if m072b==8
replace period2=0 if m072b==9
replace period2=0 if m072b==.

gen other_job=0
replace other_job=m072a*period2

* Additional Services
gen pay_serv=0
foreach var of varlist m0760* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace pay_serv=pay_serv+`var'
} 
foreach var of varlist m0770* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace pay_serv=pay_serv-`var'
} 
replace pay_serv=0 if pay_serv<0

* Additional Support
foreach var of varlist m0860*d {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
} 


foreach X in 1 2 3 4 5 6 7 8 9 10 {
	gen num`X'=0
	replace num`X'=1 if (renglon==`X')&(sex==1)&(adult==1)
	replace num`X'=2 if (renglon==`X')&(sex==2)&(adult==1)
	replace num`X'=3 if (renglon==`X')&(adult==0)	
}


foreach var of varlist m0860*c {
	gen p`var'=0
	replace p`var'=30 if `var' ==1
	replace p`var'=4 if `var' ==2
	replace p`var'=2 if `var' ==3
	replace p`var'=1 if `var' ==4
	replace p`var'=1/2 if `var' ==5
	replace p`var'=1/12 if `var' ==6
	replace p`var'=0 if `var' ==7
	replace p`var'=0 if `var' ==8
	replace p`var'=0 if `var' ==9
	replace p`var'=0 if `var' ==.
 
} 


* Receiver of support (get only first for now)
gen sup1_rec=m08601b1
gen sup2_rec=m08602b1
gen sup3_rec=m08603b1
gen sup4_rec=m08604b1
gen sup5_rec=m08605b1

* Amount of support
gen sup1_am=m08601d*pm08601c 
gen sup2_am=m08602d*pm08602c 
gen sup3_am=m08603d*pm08603c 
gen sup4_am=m08604d*pm08604c 
gen sup5_am=m08605d*pm08605c 


* Define Income Variables
gen income=0
replace income=main_job+other_job+pay_serv

gen fincome=0
replace fincome=income if (sex==2)&(adult==1)

gen mincome=0
replace mincome=income if (sex==1)&(adult==1)

gen progresa=0
replace progresa=1 if m08704a==1

* Keep income subcategories for women for summary charts
gen finc_main = 0
replace finc_main = main_job if (sex==2)&(adult==1)

gen finc_ojob = 0
replace finc_ojob = other_job if (sex==2)&(adult==1)

gen finc_payserv = 0
replace finc_payserv = pay_serv if (sex==2)&(adult==1)



*Adult woman does not work
*m062: 4-no trabajo; m063: 6- no trabajo (verifiation)
gen nfj=0
replace nfj=1 if (sex==2)&(m062==4)&(m063==6)&(anos>16)
replace nfj=0 if  (sex==2)&(m062==.)&(m063==.)&(anos>16)

gen faj = 0
replace faj = 1 if (sex==2)&(m062==1)&(anos>16) //time "at job" last week

*** INVESTMENT GOODS MAR 1999 ***


* Livestock
gen livestock=0
*in the last 6 month have you purchased any animals? how much did it cost?
foreach var of varlist m129* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace livestock=livestock+`var'/6
} 

*in the last 6 month have you sold any animals? how much did you get?
foreach var of varlist m131* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace livestock=livestock-`var'/6
}
*

* House Fixing\Upgrading
gen ind_fixhouse=0
*in the last 6 month have you made any improvements in...?
foreach var of varlist m1130* {
	replace ind_fixhouse=1 if `var'==1
} 
gen fixhouse=.

* Land
gen landcount = 0
foreach var of varlist m1170* { 
	replace landcount = landcount+1 if `var' ==.
	}

gen land=0
**How many acres is the estate (first, second)
foreach var of varlist m1170* {
	replace  `var'=0 if ( `var'==.)
	replace land=land+ `var' 
} 

replace land = . if landcount==6


* Collapse onto Households

collapse (sum) nkids=kid nadults=adult ncouples=married nkids_school=attend_school nfkids=fkid nkids_prim=kid_primary  hh_size income food alco tobacco transport services women_clothing men_clothing girls_clothing boys_clothing expenditure2 hhw_mis_inc livestock  land (max) elig treat finc_* fincome mincome progresa sup* num* nfj faj ind_fixhouse fixhouse,  by(folio)

* Sample Restrictions
drop if ncouples~=2
drop if nadults>2 
drop if hhw_mis_inc>0


* Support data
gen fsup=0
gen msup=0
gen kidsup=0

foreach Y in 1 2 3 4 5 {
foreach X in 1 2 3 4 5 6 7 8 9 10 {
	replace msup=msup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==1)
	replace fsup=fsup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==2)
	replace kidsup=kidsup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==3)	
}
}
*

tempfile data99_1
save `data99_1', replace



******************
* ENCEL Nov 1999 *
******************


use "`datdir'/ENCEL99n_2.dta", clear // read in data

gen anos=.
replace anos=n002

gen kid=0
replace kid=1 if anos<=16

gen sex=.
replace sex=1 if (n008==1)
replace sex=2 if (n008==2)

gen attend_school=0
replace attend_school=1 if (kid==1)&(n039==1)

gen fkid=0
replace fkid=1 if (kid==1)&(sex==2)

gen hh_size=1

gen kid_primary=.
replace kid_primary=1 if (attend_school==1)&(anos<=13)

gen adult=0
replace adult=1 if anos>16

gen married=0
replace married=1 if (n048==2)

* Female missing income
gen hhw_mis_inc=0
replace hhw_mis_inc=1 if (n050==.)&(n051==.)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (n050==9)&(n051==.)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (n050==.)&(n051==9)&(sex==2)&(anos>16)
replace hhw_mis_inc=1 if (n050==9)&(n051==9)&(sex==2)&(anos>16)


gen elig=0
replace elig=1 if pobreden==2

gen treat=0
replace treat=1 if contba==1



*** EXPENDITURES NOV 1999 ***


*clothing during last 6 month *
foreach var of varlist n095* {
 replace `var' = 0 if (`var'==9999)|(`var'==.)
}


* With shoes
gen women_clothing=(n09506+n09510)/6
gen men_clothing=(n09507+n09511)/6
gen girls_clothing=(n09504+n09508)/6
gen boys_clothing=(n09505+n09509)/6

*Without shoes
*gen women_clothing=(n09506)/6
*gen men_clothing=(n09507)/6
*gen girls_clothing=(n09504)/6
*gen boys_clothing=(n09505)/6

* Transportation
replace n09301=0 if (n09301==999)|(n09301==.)
replace n09302=0 if (n09302==999)|(n09302==.)
gen transport=(n09301+n09302)*4

* Tobacco
replace n09303=0 if (n09303==988)|(n09303==999)|(n09303==.)
gen tobacco=n09303*4

* Services
replace n09404=0 if (n09404==999)|(n09404==.)
gen services=n09404


*Food in past week
foreach var of varlist n072* {
 replace `var' = 0 if (`var'==988)|(`var'==999)|(`var'==.)
}
gen food=0
foreach var of varlist n072* {
 replace food=food+`var' 
}
replace food=food*4

*Alcohol in past week
gen alco=n07236*4

replace n081=0 if (n081==999)|(n081==.)
gen expenditure2=n081*4



*** INCOME NOV 1999 ***


* Main Job
replace n058a=0 if (n058a==98888)| (n058a==99999)| (n058a==.)

gen period=0
replace period=30 if n058b==1
replace period=4 if n058b==2
replace period=2 if n058b==3
replace period=1 if n058b==4
replace period=1/12 if n058b==5
replace period=0 if n058b==8
replace period=0 if n058b==9
replace period=0 if n058b==.

gen main_job=0
replace main_job=n058a*period

* Other
replace n060a1=0 if (n060a1==98888)| (n060a1==99999)| (n060a1==.)

gen period2a=0
replace period2a=30 if n060a2==1
replace period2a=4 if n060a2==2
replace period2a=2 if n060a2==3
replace period2a=1 if n060a2==4
replace period2a=1/12 if n060a2==5
replace period2a=0 if n060a2==8
replace period2a=0 if n060a2==9
replace period2a=0 if n060a2==.

replace n060b1=0 if (n060b1==98888)| (n060b1==99999)| (n060b1==.)

gen period2b=0
replace period2b=30 if n060b2==1
replace period2b=4 if n060b2==2
replace period2b=2 if n060b2==3
replace period2b=1 if n060b2==4
replace period2b=1/12 if n060b2==5
replace period2b=0 if n060b2==8
replace period2b=0 if n060b2==9
replace period2b=0 if n060b2==.


gen other_job=0
replace other_job=n060a1*period2a+n060b1*period2b

* Services
gen pay_serv=0
foreach var of varlist n0640* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace pay_serv=pay_serv+`var'
} 
foreach var of varlist n0650* {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
	replace pay_serv=pay_serv-`var'
} 
replace pay_serv=0 if pay_serv<0

* Support 

foreach var of varlist n0670*d {
 	replace `var' = 0 if (`var'==99999)|(`var'==98888)|(`var'==.)
} 

foreach X in 1 2 3 4 5 6 7 8 9 10 {
	gen num`X'=0
	replace num`X'=1 if (renglon==`X')&(sex==1)&(adult==1)
	replace num`X'=2 if (renglon==`X')&(sex==2)&(adult==1)
	replace num`X'=3 if (renglon==`X')&(adult==0)	
}
*
foreach var of varlist n0670*c {
	gen p`var'=0
	replace p`var'=30 if `var' ==1
	replace p`var'=4 if `var' ==2
	replace p`var'=2 if `var' ==3
	replace p`var'=1 if `var' ==4
	replace p`var'=1/2 if `var' ==5
	replace p`var'=1/12 if `var' ==6
	replace p`var'=0 if `var' ==7
	replace p`var'=0 if `var' ==8
	replace p`var'=0 if `var' ==9
	replace p`var'=0 if `var' ==.
 
} 


* receiver of support (get only first for now)
gen sup1_rec=n06701b1
gen sup2_rec=n06702b1
gen sup3_rec=n06703b1
gen sup4_rec=n06704b1
gen sup5_rec=n06705b1

* amount of support
gen sup1_am=n06701d*pn06701c 
gen sup2_am=n06702d*pn06702c 
gen sup3_am=n06703d*pn06703c 
gen sup4_am=n06704d*pn06704c 
gen sup5_am=n06705d*pn06705c 

* Define Incomes
gen income=0
replace income=main_job+other_job+pay_serv

gen fincome=0
replace fincome=income if (sex==2)&(adult==1)

gen mincome=0
replace mincome=income if (sex==1)&(adult==1)

* Keep income subcategories for women for summary charts
gen finc_main = 0
replace finc_main = main_job if (sex==2)&(adult==1)

gen finc_ojob = 0
replace finc_ojob = other_job if (sex==2)&(adult==1)

gen finc_payserv = 0
replace finc_payserv = pay_serv if (sex==2)&(adult==1)



*Adult woman does not work
*n050: 4-no trabajo; n051: 6- no trabajo (verifiation)
gen nfj=0
replace nfj=1 if (sex==2)&(n050==4)&(n051==6)&(anos>16)
replace nfj=0 if  (sex==2)&(n050==.)&(n051==.)&(anos>16)

gen faj = 0
replace faj = 1 if (sex==2)&(n050==1)&(anos>16) //time "at job" last week

*** INVESTMENT GOODS NOV 1999 ***


* Livestock * NO DATA in that survey*


* Fix the house * NO DATA in that survey*



*Land 
gen landcount = 0
foreach var of varlist n100* { 
	replace landcount = landcount+1 if `var' ==.
	}


gen land=0

**How many acres is the estate (first, second)
foreach var of varlist n100* {
	replace  `var'=0 if ( `var'==.)
	replace land=land+ `var' 
} 


replace land = . if landcount==6


* Collapse on Household
collapse (sum) nkids=kid nadults=adult ncouples=married nkids_school=attend_school nfkids=fkid nkids_prim=kid_primary  hh_size income food alco tobacco transport services women_clothing men_clothing girls_clothing boys_clothing  expenditure2  hhw_mis_inc land (max) elig treat finc_* fincome mincome  sup* num* nfj faj ,  by(folio)


* Sample Selection
drop if ncouples~=2
drop if nadults>2 
drop if hhw_mis_inc>0

* Support Data

gen fsup=0
gen msup=0
gen kidsup=0

foreach Y in 1 2 3 4 5 {
foreach X in 1 2 3 4 5 6 7 8 9 10 {
	replace msup=msup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==1)
	replace fsup=fsup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==2)
	replace kidsup=kidsup+sup`Y'_am if (sup`Y'_rec==`X')&(num`X'==3)	
}
}
*

* save datafile
tempfile data99_2
save `data99_2', replace


**********************
* PROGRESA TRANSFERS *
**********************


* Rural Transfers
use "`datdir'/rural_transfers.dta", clear

rename folio2003 folio
keep folio tot* 
drop if folio==0 //this seems to be code for missing folio numbers
duplicates tag folio, gen(dup_folio)
drop if dup_folio>0 // get rid of duplicates 

* Several Different Measures of Transfers
* v1 - average monthly transfers in 6 month interval around survey dates

gen v1_progresa_pay_98_2 = (total_98_4+total_98_5+total_98_6)/6
gen v1_progresa_pay_99_1 = (total_99_1+total_99_2+total_99_3)/6
gen v1_progresa_pay_99_2 = (total_99_4+tot_99_5  +  tot_99_6)/6 // variable name change after 99_4 to abbreviate total...

* v2 - Half of two month transfer around survey date

gen v2_progresa_pay_98_2 = (total_98_5)/2
gen v2_progresa_pay_99_1 = (total_99_2)/2
gen v2_progresa_pay_99_2 = (tot_99_6)/2   // variable name change after 99_4 to abbreviate total...

* v3 - Average monlthy payment in 6month previous to survey

gen v3_progresa_pay_98_2 = (total_98_3+total_98_4+total_98_5)/6
gen v3_progresa_pay_99_1 = (total_98_6+total_99_1+total_99_2)/6
gen v3_progresa_pay_99_2 = (total_99_3+total_99_4+tot_99_5)/6 


keep folio v1_* v2_* v3_*


sort folio

tempfile data_transfers
save `data_transfers'


*****************************************
* COMBINE DATA TO CREATE MASTER DATASET *
*****************************************


* Merge in Oct 1998 Data *

use `data97', clear
merge 1:1 folio using `data98_2'
drop if _merge==2
drop _merge

sort folio
merge 1:1 folio using `data_transfers' 
drop if _merge==2
drop _merge

gen dum98o   = 1 /* dummy for year */
gen tdum     = 1 /* dummy for panel regs */

gen transf_avg  = v1_progresa_pay_98_2 

tempfile merged98
save `merged98', replace


* Merge in Mar 1999 Data *


use `data97', clear
merge 1:1 folio using `data99_1'
drop if _merge==2
drop _merge

sort folio
merge 1:1 folio using `data_transfers'
drop if _merge==2
drop _merge

gen dum99m   = 1 /* dummy for year */
gen tdum     = 2 /* dummy for panel regs */

gen transf_avg  = v1_progresa_pay_99_1

tempfile merged99_1
save `merged99_1', replace


* Merge in Nov 1999 Data *


use `data97', clear
merge 1:1 folio using `data99_2'
drop if _merge ==2
drop    _merge

sort folio
merge 1:1 folio using `data_transfers'
drop if _merge==2
drop _merge

gen dum99n   = 1 /* dummy for year */
gen tdum     = 3 /* dummy for panel regs */

gen transf_avg  = v1_progresa_pay_99_2

tempfile merged99_2
save `merged99_2'


* Pool Data Sets *

use `merged98'
append using `merged99_1'
append using `merged99_2'

save "`outdir'/Progresa_Regressions_Data.dta", replace //save master data set for regressions
